@@ -69,8 +69,7 @@ class Util:
                            partial_score_exact,
                            partial_score_keywords,
                            partial_score_points,
-                           levsthn_threshold = 0.8,
-                           ):
+                           levsthn_threshold = 0.8):
         score = 0
         try:
             # sanitize inputs
@@ -113,8 +112,8 @@ class Util:
         finally:
             # if the solution isn't exact, apply other rules
             # = check for keywords in SQL.
+            partial_score = 0
             if round(score, 2) < no_of_points:
-                partial_score = 0
                 print(f'> Score for this task {score:.2f} is less than {no_of_points}, applying partial scoring.')
                 for i in partial_score_keywords:
                     if i in query_text.upper():
